import {select ,
        geoPath ,
        geoEqualEarth ,
        zoom ,
        event,
        schemeCategory10,
        scaleOrdinal,
        schemeSpectral
      } from 'd3';

import  { loadAndProcessData } from './loadAndProcessData';
import {colorLegend } from './colorLegend';

const svg = select('svg');

const projection = geoEqualEarth();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const colorLegendG = svg.append('g')
	.attr('transform' ,`translate(30,300)`);

 g.append('path')
		.attr('class' ,'sphere')
		.attr('d' ,pathGenerator({type :'Sphere'}));

svg.call(zoom().on('zoom' ,() => {
	g.attr('transform' , event.transform);
}));

const colorScale = scaleOrdinal();

const colorValue =d => d.properties.economy;

loadAndProcessData().then(countries => {
  
  	colorScale
      	.domain(countries.features.map(colorValue))//to avoid duplicates
  			.domain(colorScale.domain().sort().reverse())//to sort values
  			.range(schemeSpectral[colorScale.domain().length]);
  	
  	
    colorLegendG.call(colorLegend, {
        colorScale,
        circleRadius : 8,
        spacing : 20,
        textOffset :12,
      	backGroundRectWidth : 235
      });
  
  	g.selectAll('path') .data(countries.features) //data join
				.enter().append('path') 	
  				.attr('class' ,'country')
  				.attr('d' ,pathGenerator)
  				.attr('fill' , d => colorScale(colorValue(d)))
  			.append('title')
  				.text(d => d.properties.name + ' : ' + colorValue(d));
		});
 